@@ -1,6 +1,7 @@
 import json
 
-from moto.core.utils import headers_to_dict
+from moto.core.responses import BaseResponse
+from moto.core.utils import camelcase_to_underscores
 from .models import dynamodb_backend, dynamo_json_dump
 
 
@@ -27,38 +28,47 @@ GET_SESSION_TOKEN_RESULT = """
 </GetSessionTokenResponse>"""
 
 
-def sts_handler(uri, body, headers):
+def sts_handler():
     return GET_SESSION_TOKEN_RESULT
 
 
-class DynamoHandler(object):
+class DynamoHandler(BaseResponse):
 
-    def __init__(self, uri, body, headers):
-        self.uri = uri
-        self.body = body
-        self.headers = headers
-
-    def get_method_name(self, headers):
+    def get_endpoint_name(self, headers):
         """Parses request headers and extracts part od the X-Amz-Target
         that corresponds to a method of DynamoHandler
 
         ie: X-Amz-Target: DynamoDB_20111205.ListTables -> ListTables
         """
-        match = headers.get('X-Amz-Target')
+        # Headers are case-insensitive. Probably a better way to do this.
+        match = headers.get('x-amz-target') or headers.get('X-Amz-Target')
         if match:
             return match.split(".")[1]
 
     def error(self, type_, status=400):
-        return dynamo_json_dump({'__type': type_}), dict(status=400)
+        return status, self.response_headers, dynamo_json_dump({'__type': type_})
 
-    def dispatch(self):
-        method = self.get_method_name(self.headers)
-        if method:
-            return getattr(self, method)(self.uri, self.body, self.headers)
+    def call_action(self):
+        if 'GetSessionToken' in self.body:
+            return 200, self.response_headers, sts_handler()
+
+        self.body = json.loads(self.body or '{}')
+        endpoint = self.get_endpoint_name(self.headers)
+        if endpoint:
+            endpoint = camelcase_to_underscores(endpoint)
+            response = getattr(self, endpoint)()
+            if isinstance(response, basestring):
+                return 200, self.response_headers, response
+
+            else:
+                status_code, new_headers, response_content = response
+                self.response_headers.update(new_headers)
+                return status_code, self.response_headers, response_content
         else:
-            return "", dict(status=404)
+            return 404, self.response_headers, ""
 
-    def ListTables(self, uri, body, headers):
+    def list_tables(self):
+        body = self.body
         limit = body.get('Limit')
         if body.get("ExclusiveStartTableName"):
             last = body.get("ExclusiveStartTableName")
@@ -75,7 +85,8 @@ class DynamoHandler(object):
             response["LastEvaluatedTableName"] = tables[-1]
         return dynamo_json_dump(response)
 
-    def CreateTable(self, uri, body, headers):
+    def create_table(self):
+        body = self.body
         name = body['TableName']
 
         key_schema = body['KeySchema']
@@ -102,8 +113,8 @@ class DynamoHandler(object):
         )
         return dynamo_json_dump(table.describe)
 
-    def DeleteTable(self, uri, body, headers):
-        name = body['TableName']
+    def delete_table(self):
+        name = self.body['TableName']
         table = dynamodb_backend.delete_table(name)
         if table:
             return dynamo_json_dump(table.describe)
@@ -111,16 +122,16 @@ class DynamoHandler(object):
             er = 'com.amazonaws.dynamodb.v20111205#ResourceNotFoundException'
             return self.error(er)
 
-    def UpdateTable(self, uri, body, headers):
-        name = body['TableName']
-        throughput = body["ProvisionedThroughput"]
+    def update_table(self):
+        name = self.body['TableName']
+        throughput = self.body["ProvisionedThroughput"]
         new_read_units = throughput["ReadCapacityUnits"]
         new_write_units = throughput["WriteCapacityUnits"]
         table = dynamodb_backend.update_table_throughput(name, new_read_units, new_write_units)
         return dynamo_json_dump(table.describe)
 
-    def DescribeTable(self, uri, body, headers):
-        name = body['TableName']
+    def describe_table(self):
+        name = self.body['TableName']
         try:
             table = dynamodb_backend.tables[name]
         except KeyError:
@@ -128,9 +139,9 @@ class DynamoHandler(object):
             return self.error(er)
         return dynamo_json_dump(table.describe)
 
-    def PutItem(self, uri, body, headers):
-        name = body['TableName']
-        item = body['Item']
+    def put_item(self):
+        name = self.body['TableName']
+        item = self.body['Item']
         result = dynamodb_backend.put_item(name, item)
         if result:
             item_dict = result.to_json()
@@ -140,8 +151,8 @@ class DynamoHandler(object):
             er = 'com.amazonaws.dynamodb.v20111205#ResourceNotFoundException'
             return self.error(er)
 
-    def BatchWriteItem(self, uri, body, headers):
-        table_batches = body['RequestItems']
+    def batch_write_item(self):
+        table_batches = self.body['RequestItems']
 
         for table_name, table_requests in table_batches.iteritems():
             for table_request in table_requests:
@@ -171,23 +182,28 @@ class DynamoHandler(object):
 
         return dynamo_json_dump(response)
 
-    def GetItem(self, uri, body, headers):
-        name = body['TableName']
-        key = body['Key']
+    def get_item(self):
+        name = self.body['TableName']
+        key = self.body['Key']
         hash_key = key['HashKeyElement']
         range_key = key.get('RangeKeyElement')
-        attrs_to_get = body.get('AttributesToGet')
-        item = dynamodb_backend.get_item(name, hash_key, range_key)
+        attrs_to_get = self.body.get('AttributesToGet')
+        try:
+            item = dynamodb_backend.get_item(name, hash_key, range_key)
+        except ValueError:
+            er = 'com.amazon.coral.validate#ValidationException'
+            return self.error(er, status=400)
         if item:
             item_dict = item.describe_attrs(attrs_to_get)
             item_dict['ConsumedCapacityUnits'] = 0.5
             return dynamo_json_dump(item_dict)
         else:
+            # Item not found
             er = 'com.amazonaws.dynamodb.v20111205#ResourceNotFoundException'
-            return self.error(er)
+            return self.error(er, status=404)
 
-    def BatchGetItem(self, uri, body, headers):
-        table_batches = body['RequestItems']
+    def batch_get_item(self):
+        table_batches = self.body['RequestItems']
 
         results = {
             "Responses": {
@@ -209,10 +225,10 @@ class DynamoHandler(object):
             results["Responses"][table_name] = {"Items": items, "ConsumedCapacityUnits": 1}
         return dynamo_json_dump(results)
 
-    def Query(self, uri, body, headers):
-        name = body['TableName']
-        hash_key = body['HashKeyValue']
-        range_condition = body.get('RangeKeyCondition')
+    def query(self):
+        name = self.body['TableName']
+        hash_key = self.body['HashKeyValue']
+        range_condition = self.body.get('RangeKeyCondition')
         if range_condition:
             range_comparison = range_condition['ComparisonOperator']
             range_values = range_condition['AttributeValueList']
@@ -240,11 +256,11 @@ class DynamoHandler(object):
         #     }
         return dynamo_json_dump(result)
 
-    def Scan(self, uri, body, headers):
-        name = body['TableName']
+    def scan(self):
+        name = self.body['TableName']
 
         filters = {}
-        scan_filters = body.get('ScanFilter', {})
+        scan_filters = self.body.get('ScanFilter', {})
         for attribute_name, scan_filter in scan_filters.iteritems():
             # Keys are attribute names. Values are tuples of (comparison, comparison_value)
             comparison_operator = scan_filter["ComparisonOperator"]
@@ -272,12 +288,12 @@ class DynamoHandler(object):
         #     }
         return dynamo_json_dump(result)
 
-    def DeleteItem(self, uri, body, headers):
-        name = body['TableName']
-        key = body['Key']
+    def delete_item(self):
+        name = self.body['TableName']
+        key = self.body['Key']
         hash_key = key['HashKeyElement']
         range_key = key.get('RangeKeyElement')
-        return_values = body.get('ReturnValues', '')
+        return_values = self.body.get('ReturnValues', '')
         item = dynamodb_backend.delete_item(name, hash_key, range_key)
         if item:
             if return_values == 'ALL_OLD':
@@ -289,10 +305,3 @@ class DynamoHandler(object):
         else:
             er = 'com.amazonaws.dynamodb.v20111205#ResourceNotFoundException'
             return self.error(er)
-
-
-def handler(uri, body, headers):
-    if 'GetSessionToken' in body:
-        return sts_handler(uri, body, headers)
-    body = json.loads(body or '{}')
-    return DynamoHandler(uri, body, headers_to_dict(headers)).dispatch()
