@@ -1,10 +1,11 @@
 from jinja2 import Template
 
+from moto.core.responses import BaseResponse
 from moto.ec2.models import ec2_backend
 from moto.ec2.utils import instance_ids_from_querystring
 
 
-class General(object):
+class General(BaseResponse):
     def get_console_output(self):
         self.instance_ids = instance_ids_from_querystring(self.querystring)
         instance_id = self.instance_ids[0]
