@@ -1,10 +1,7 @@
-from jinja2 import Template
-
-from moto.ec2.models import ec2_backend
-from moto.ec2.utils import resource_ids_from_querystring
+from moto.core.responses import BaseResponse
 
 
-class PlacementGroups(object):
+class PlacementGroups(BaseResponse):
     def create_placement_group(self):
         raise NotImplementedError('PlacementGroups.create_placement_group is not yet implemented')
 
