@@ -1,10 +1,7 @@
-from jinja2 import Template
-
-from moto.ec2.models import ec2_backend
-from moto.ec2.utils import resource_ids_from_querystring
+from moto.core.responses import BaseResponse
 
 
-class VMExport(object):
+class VMExport(BaseResponse):
     def cancel_export_task(self):
         raise NotImplementedError('VMExport.cancel_export_task is not yet implemented')
 
