@@ -2,6 +2,6 @@ from moto.s3.models import S3Backend
 
 
 class S3BucketPathBackend(S3Backend):
-    True
+    pass
 
 s3bucket_path_backend = S3BucketPathBackend()
